@@ -24,7 +24,7 @@ class BatchModifyDomainInfoRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Domains: 批量修改的域名。
         :type Domains: list of str
         :param TemplateId: 模板ID。
@@ -58,7 +58,7 @@ class BatchModifyDomainInfoResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 日志ID
         :type LogId: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -79,7 +79,7 @@ class BatchStatus(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 批量任务id
         :type LogId: int
         :param Status: 批量任务状态  doing：进行中  success：成功  failed：失败  partial_success：部分成功
@@ -111,7 +111,7 @@ class CertificateInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CertificateCode: 证件号码。
         :type CertificateCode: str
         :param CertificateType: 证件类型。
@@ -171,7 +171,7 @@ class CheckBatchStatusRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogIds: 操作日志 ID数组，最多 200 个
         :type LogIds: list of int non-negative
         """
@@ -195,7 +195,7 @@ class CheckBatchStatusResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param StatusSet: 批量任务状态集
         :type StatusSet: list of BatchStatus
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -221,7 +221,7 @@ class CheckDomainRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DomainName: 所查询域名名称
         :type DomainName: str
         :param Period: 年限。该参数为空时无法查询溢价词域名
@@ -249,7 +249,7 @@ class CheckDomainResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DomainName: 所查询域名名称
         :type DomainName: str
         :param Available: 是否能够注册
@@ -322,7 +322,7 @@ class ContactInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param OrganizationNameCN: 注册人（中文）
         :type OrganizationNameCN: str
         :param OrganizationName: 注册人（英文）
@@ -406,7 +406,7 @@ class CreateDomainBatchRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TemplateId: 模板ID。详情请查看：[获取模板列表](https://cloud.tencent.com/document/product/242/48940)
         :type TemplateId: str
         :param Period: 购买域名的年限，可选值：[1-10]
@@ -452,7 +452,7 @@ class CreateDomainBatchResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 批量日志ID
 注意：此字段可能返回 null，表示取不到有效值。
         :type LogId: int
@@ -468,13 +468,62 @@ class CreateDomainBatchResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class CreatePhoneEmailRequest(AbstractModel):
+    """CreatePhoneEmail请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Code: 手机号或者邮箱
+        :type Code: str
+        :param Type: 1：手机   2：邮箱
+        :type Type: int
+        :param VerifyCode: 验证码
+        :type VerifyCode: str
+        """
+        self.Code = None
+        self.Type = None
+        self.VerifyCode = None
+
+
+    def _deserialize(self, params):
+        self.Code = params.get("Code")
+        self.Type = params.get("Type")
+        self.VerifyCode = params.get("VerifyCode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CreatePhoneEmailResponse(AbstractModel):
+    """CreatePhoneEmail返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class CreateTemplateRequest(AbstractModel):
     """CreateTemplate请求参数结构体
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param ContactInfo: 联系人信息
         :type ContactInfo: :class:`tencentcloud.domain.v20180808.models.ContactInfo`
         :param CertificateInfo: 证件信息
@@ -506,7 +555,7 @@ class CreateTemplateResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Template: 模板信息
         :type Template: :class:`tencentcloud.domain.v20180808.models.TemplateInfo`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -523,13 +572,58 @@ class CreateTemplateResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DeletePhoneEmailRequest(AbstractModel):
+    """DeletePhoneEmail请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Code: 手机或者邮箱
+        :type Code: str
+        :param Type: 1：手机  2：邮箱
+        :type Type: int
+        """
+        self.Code = None
+        self.Type = None
+
+
+    def _deserialize(self, params):
+        self.Code = params.get("Code")
+        self.Type = params.get("Type")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DeletePhoneEmailResponse(AbstractModel):
+    """DeletePhoneEmail返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class DeleteTemplateRequest(AbstractModel):
     """DeleteTemplate请求参数结构体
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param TemplateId: 模板ID
         :type TemplateId: str
         """
@@ -553,7 +647,7 @@ class DeleteTemplateResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -570,7 +664,7 @@ class DescribeBatchOperationLogDetailsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 日志ID。
         :type LogId: int
         :param Offset: 偏移量，默认为0。
@@ -602,7 +696,7 @@ class DescribeBatchOperationLogDetailsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 总数量。
         :type TotalCount: int
         :param DomainBatchDetailSet: 日志详情列表。
@@ -633,7 +727,7 @@ class DescribeBatchOperationLogsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Offset: 偏移量，默认为0。
         :type Offset: int
         :param Limit: 返回数量，默认为20，最大值为200。
@@ -661,7 +755,7 @@ class DescribeBatchOperationLogsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 总数量
         :type TotalCount: int
         :param DomainBatchLogSet: 日志列表
@@ -692,7 +786,7 @@ class DescribeDomainBaseInfoRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Domain: 域名
         :type Domain: str
         """
@@ -716,7 +810,7 @@ class DescribeDomainBaseInfoResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DomainInfo: 域名信息
         :type DomainInfo: :class:`tencentcloud.domain.v20180808.models.DomainBaseInfo`
         :param Uin: 用户Uin
@@ -744,7 +838,7 @@ class DescribeDomainNameListRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Offset: 偏移量，默认为0
         :type Offset: int
         :param Limit: 返回数量，默认为20，取值范围[1,100]
@@ -772,7 +866,7 @@ class DescribeDomainNameListResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DomainSet: 域名信息集合
 注意：此字段可能返回 null，表示取不到有效值。
         :type DomainSet: list of DomainList
@@ -803,7 +897,7 @@ class DescribeDomainPriceListRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TldList: 查询价格的后缀列表。默认则为全部后缀
         :type TldList: list of str
         :param Year: 查询购买的年份，默认会列出所有年份的价格
@@ -835,7 +929,7 @@ class DescribeDomainPriceListResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PriceList: 域名价格列表
         :type PriceList: list of PriceInfo
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -855,20 +949,86 @@ class DescribeDomainPriceListResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribePhoneEmailListRequest(AbstractModel):
+    """DescribePhoneEmailList请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Type: 0：所有类型  1：手机  2：邮箱，默认0
+        :type Type: int
+        :param Offset: 偏移量，默认为0
+        :type Offset: int
+        :param Limit: 返回数量，默认为20，取值范围[1,200]
+        :type Limit: int
+        :param Code: 手机或者邮箱精确搜索
+        :type Code: str
+        """
+        self.Type = None
+        self.Offset = None
+        self.Limit = None
+        self.Code = None
+
+
+    def _deserialize(self, params):
+        self.Type = params.get("Type")
+        self.Offset = params.get("Offset")
+        self.Limit = params.get("Limit")
+        self.Code = params.get("Code")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribePhoneEmailListResponse(AbstractModel):
+    """DescribePhoneEmailList返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param PhoneEmailList: 手机或者邮箱列表
+        :type PhoneEmailList: list of PhoneEmailData
+        :param TotalCount: 总数量。
+        :type TotalCount: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.PhoneEmailList = None
+        self.TotalCount = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("PhoneEmailList") is not None:
+            self.PhoneEmailList = []
+            for item in params.get("PhoneEmailList"):
+                obj = PhoneEmailData()
+                obj._deserialize(item)
+                self.PhoneEmailList.append(obj)
+        self.TotalCount = params.get("TotalCount")
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeTemplateListRequest(AbstractModel):
     """DescribeTemplateList请求参数结构体
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param Offset: 偏移量，默认为0。
         :type Offset: int
         :param Limit: 返回数量，默认为20，最大值为100。
         :type Limit: int
         :param Type: 用户注册类型，默认:all , 个人：I ,企业: E
         :type Type: str
-        :param Status: 认证状态：未实名认证:NotUpload, 实名审核中:InAudit，已实名认证:Approved，实名审核失败:Reject
+        :param Status: 认证状态：未实名审核:NotUpload, 实名审核中:InAudit，已实名审核:Approved，实名审核失败:Reject，更新手机邮箱:NotVerified。
         :type Status: str
         :param Keyword: 域名所有者筛选
         :type Keyword: str
@@ -901,7 +1061,7 @@ class DescribeTemplateListResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 模板数量。
         :type TotalCount: int
         :param TemplateSet: 模板详细信息列表。
@@ -931,7 +1091,7 @@ class DescribeTemplateRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TemplateId: 模板ID
         :type TemplateId: str
         """
@@ -955,7 +1115,7 @@ class DescribeTemplateResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Template: 模板信息
         :type Template: :class:`tencentcloud.domain.v20180808.models.TemplateInfo`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -978,7 +1138,7 @@ class DomainBaseInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DomainId: 域名资源ID。
         :type DomainId: str
         :param DomainName: 域名名称。
@@ -1096,7 +1256,7 @@ class DomainBatchDetailSet(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Id: 详情ID
         :type Id: int
         :param Domain: 域名
@@ -1144,7 +1304,7 @@ class DomainBatchLogSet(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 日志ID
         :type LogId: int
         :param Number: 数量
@@ -1182,7 +1342,7 @@ class DomainList(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param IsPremium: 是否是溢价域名：
 ture 是    
 false 不是
@@ -1254,7 +1414,7 @@ class ModifyDomainDNSBatchRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Domains: 批量操作的域名。
         :type Domains: list of str
         :param Dns: 域名DNS 数组。
@@ -1282,7 +1442,7 @@ class ModifyDomainDNSBatchResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 日志ID。
         :type LogId: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1303,7 +1463,7 @@ class ModifyDomainOwnerBatchRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Domains: 要过户的域名。
         :type Domains: list of str
         :param NewOwnerUin: 转入账户的uin。
@@ -1335,7 +1495,7 @@ class ModifyDomainOwnerBatchResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 日志id
         :type LogId: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1350,13 +1510,49 @@ class ModifyDomainOwnerBatchResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class PhoneEmailData(AbstractModel):
+    """手机号邮箱列表
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Code: 手机号或者邮箱
+        :type Code: str
+        :param Type: 1：手机  2：邮箱
+        :type Type: int
+        :param CreatedOn: 创建时间
+        :type CreatedOn: str
+        :param CheckStatus: 1=控制台校验，2=第三方校验
+        :type CheckStatus: int
+        """
+        self.Code = None
+        self.Type = None
+        self.CreatedOn = None
+        self.CheckStatus = None
+
+
+    def _deserialize(self, params):
+        self.Code = params.get("Code")
+        self.Type = params.get("Type")
+        self.CreatedOn = params.get("CreatedOn")
+        self.CheckStatus = params.get("CheckStatus")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class PriceInfo(AbstractModel):
     """域名价格信息
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param Tld: 域名后缀，例如.com
         :type Tld: str
         :param Year: 购买年限，范围[1-10]
@@ -1396,7 +1592,7 @@ class RenewDomainBatchRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Period: 域名续费的年限。
         :type Period: int
         :param Domains: 批量续费的域名。
@@ -1435,7 +1631,7 @@ class RenewDomainBatchResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 操作日志ID。
         :type LogId: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1450,13 +1646,58 @@ class RenewDomainBatchResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class SendPhoneEmailCodeRequest(AbstractModel):
+    """SendPhoneEmailCode请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Code: 手机或者邮箱号。
+        :type Code: str
+        :param Type: 1：手机  2：邮箱。
+        :type Type: int
+        """
+        self.Code = None
+        self.Type = None
+
+
+    def _deserialize(self, params):
+        self.Code = params.get("Code")
+        self.Type = params.get("Type")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class SendPhoneEmailCodeResponse(AbstractModel):
+    """SendPhoneEmailCode返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class SetDomainAutoRenewRequest(AbstractModel):
     """SetDomainAutoRenew请求参数结构体
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param DomainId: 域名ID。
         :type DomainId: str
         :param AutoRenew: AutoRenew 有三个可选值：
@@ -1487,7 +1728,7 @@ class SetDomainAutoRenewResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -1504,7 +1745,7 @@ class TemplateInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TemplateId: 模板ID
         :type TemplateId: str
         :param AuditStatus: 认证状态：未实名认证:NotUpload, 实名审核中:InAudit，已实名认证:Approved，实名审核失败:Reject
@@ -1572,7 +1813,7 @@ class TransferInDomainBatchRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Domains: 转入的域名名称数组。
         :type Domains: list of str
         :param PassWords: 域名转移码数组。
@@ -1620,7 +1861,7 @@ class TransferInDomainBatchResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 日志ID
         :type LogId: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1641,7 +1882,7 @@ class TransferProhibitionBatchRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Domains: 批量操作的域名。
         :type Domains: list of str
         :param Status: 是否开启禁止域名转移。
@@ -1671,7 +1912,7 @@ class TransferProhibitionBatchResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 日志ID
         :type LogId: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1692,7 +1933,7 @@ class UpdateProhibitionBatchRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Domains: 批量操作的域名。
         :type Domains: list of str
         :param Status: 是否开启禁止域名更新。
@@ -1722,7 +1963,7 @@ class UpdateProhibitionBatchResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param LogId: 日志ID
         :type LogId: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1743,7 +1984,7 @@ class UploadImageRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ImageFile: 资质照片，照片的base64编码。
         :type ImageFile: str
         """
@@ -1767,7 +2008,7 @@ class UploadImageResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AccessUrl: 资质照片地址。
         :type AccessUrl: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
