@@ -62,6 +62,9 @@ FAILEDOPERATION_DECRYPTSYSTEMERROR = 'FailedOperation.DecryptSystemError'
 # 文件下载失败。
 FAILEDOPERATION_DOWNLOADERROR = 'FailedOperation.DownLoadError'
 
+# 文件下载超时。
+FAILEDOPERATION_DOWNLOADTIMEOUTERROR = 'FailedOperation.DownLoadTimeoutError'
+
 # 图片内容为空。
 FAILEDOPERATION_EMPTYIMAGEERROR = 'FailedOperation.EmptyImageError'
 
