@@ -314,7 +314,7 @@ class ScfClient(AbstractClient):
 
 
     def DeleteReservedConcurrencyConfig(self, request):
-        """删除函数的保留并发配置。
+        """删除函数的最大独占配额配置。
 
         :param request: Request instance for DeleteReservedConcurrencyConfig.
         :type request: :class:`tencentcloud.scf.v20180416.models.DeleteReservedConcurrencyConfigRequest`
@@ -593,8 +593,36 @@ class ScfClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GetRequestStatus(self, request):
+        """该接口根据指定的查询条件返回函数单个请求运行状态。
+
+        :param request: Request instance for GetRequestStatus.
+        :type request: :class:`tencentcloud.scf.v20180416.models.GetRequestStatusRequest`
+        :rtype: :class:`tencentcloud.scf.v20180416.models.GetRequestStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("GetRequestStatus", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetRequestStatusResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetReservedConcurrencyConfig(self, request):
-        """获取函数的保留并发详情。
+        """获取函数的最大独占配额详情。
 
         :param request: Request instance for GetReservedConcurrencyConfig.
         :type request: :class:`tencentcloud.scf.v20180416.models.GetReservedConcurrencyConfigRequest`
@@ -649,6 +677,34 @@ class ScfClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def InvokeFunction(self, request):
+        """SCF同步调用函数接口
+
+        :param request: Request instance for InvokeFunction.
+        :type request: :class:`tencentcloud.scf.v20180416.models.InvokeFunctionRequest`
+        :rtype: :class:`tencentcloud.scf.v20180416.models.InvokeFunctionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("InvokeFunction", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.InvokeFunctionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ListAliases(self, request):
         """返回一个函数下的全部别名，可以根据特定函数版本过滤。
 
@@ -958,7 +1014,7 @@ class ScfClient(AbstractClient):
 
 
     def PutReservedConcurrencyConfig(self, request):
-        """设置函数保留并发
+        """设置函数最大独占配额
 
         :param request: Request instance for PutReservedConcurrencyConfig.
         :type request: :class:`tencentcloud.scf.v20180416.models.PutReservedConcurrencyConfigRequest`
